# SVT STAR_Voting_Tool
<picture>
 <source media="(prefers-color-scheme: dark)" srcset="https://upload.wikimedia.org/wikipedia/commons/thumb/c/cf/2021_Ballots_Andre-Ella.jpg/284px-2021_Ballots_Andre-Ella.jpg">
 <source media="(prefers-color-scheme: light)" srcset="https://upload.wikimedia.org/wikipedia/commons/thumb/c/cf/2021_Ballots_Andre-Ella.jpg/284px-2021_Ballots_Andre-Ella.jpg">
 <img alt="Image of a standard STAR ballot" src="https://upload.wikimedia.org/wikipedia/commons/thumb/c/cf/2021_Ballots_Andre-Ella.jpg/284px-2021_Ballots_Andre-Ella.jpg">
</picture>

 This tool is created to help faciliate the adoption of STAR elections in an open and transparent manner.

## What is a STAR Election?

In STAR, voters are given a score ballot (or ratings ballot) on which each voter scores candidates with a number from 0 up to 5, with 0 representing "worst" and 5 representing "best."

The scores for each candidate are then summed, and the two highest-scored candidates are selected as finalists.

In the automatic runoff round, the finalist who was given a higher score on a greater number of ballots is selected as the winner.
